@@ -1,3 +1,45 @@
+import plotly.express as px
+import pandas as pd
+
+def plot_orderbook(orderbook_df = None, id=False, amount_to_pass =5000, pair='free'):
+    if id >= 0:
+        df = orderbook_df[(orderbook_df['id'] == id)].copy()
+    else:
+        raise Exception('No id provided')
+
+    bid_df = df[df.type == 'bid'].copy()
+    ask_df = df[df.type == 'ask'].copy()
+
+    bid_df.sort_values('price', ascending=False, inplace=True)
+    bid_df['cumulative_quantity'] = bid_df['amount'].cumsum()
+    bid_df['to_keep'] = bid_df['cumulative_quantity']-amount_to_pass
+    bid_df['to_keep'] = bid_df['to_keep']<=0
+    bid_df['to_keep'] = bid_df['to_keep'].shift(1, axis=0)
+    bid_df['to_keep'] = bid_df['to_keep'].fillna(True)
+    bid_pass_df = bid_df[bid_df['to_keep']].copy()
+
+    ask_df.sort_values('price', ascending=True, inplace=True)
+    ask_df['cumulative_quantity'] = ask_df['amount'].cumsum()
+    ask_df['to_keep'] = ask_df['cumulative_quantity']-amount_to_pass
+    ask_df['to_keep'] = ask_df['to_keep']<=0
+    ask_df['to_keep'] = ask_df['to_keep'].shift(1, axis=0)
+    ask_df['to_keep'] = ask_df['to_keep'].fillna(True)
+    ask_pass_df = ask_df[ask_df['to_keep']].copy()
+    ask_pass_df['type']='ask'
+    bid_pass_df['type']='bid'
+
+    all_data_df = pd.concat([bid_pass_df[['price','cumulative_quantity','type']].copy(),ask_pass_df[['price','cumulative_quantity','type']].copy()])
+
+    all_data_df.sort_values(by=['price'], ascending = True, inplace = True)
+
+    fig = plot_order_book(data_df=all_data_df)
+    return fig
+
+
+def plot_order_book(data_df):
+    fig = px.line(data_df, x="price", y="cumulative_quantity", color="type",markers=True,title="order book")
+    return fig
+
 
 def process_orderbook_metrics(orderbook_df = None, id=False, amounts_to_pass = [100,500,1000,5000,10000,50000,100000], pair='free'):
     if id >= 0:
